#!/bin/bash

# Editables
wwwPath="/var/www/html"
apacheGroup="www-data"

# Do not edit
overwrite=false

# Make sure we run as root
if [[ $EUID -ne 0 ]]; then
  echo "Please run this command with superuser privileges"
  exit 1
fi

# Create the opt and www root folders
if [ ! -d "$wwwPath" ]; then
	echo "The Apache root path of $wwwPath does not exist."
	echo "Ensure Apache is installed and ensure the wwwPath variable in this script points to the www-root folder."
	exit 1
fi

# Choose name
echo "Choose the application name (e.g. provisioningApp)."
echo -n ">"
read appName

# Check opt folder existence
if [ -d "/opt/RedstorProvision/$appName" ] || [ -d "$wwwPath/$appName" ]; then
	echo "There already exists /opt/RedstorProvision/$appName or $wwwPath/$appName."
	echo "If you proceed, the existing installation will be overwritten."
        echo "The config will be backed up automatically, but you will need to re-populate the config file."
        echo "Overwrite existing installation? (y/n)"
        echo -n ">"
        read promptOverwrite 
        if [ "$promptOverwrite" == "y" ]; then
            overwrite=true
        else
            echo "Quitting"
            exit
        fi
fi

if [ overwrite ]; then
    if [ -f "/opt/RedstorProvision/$appName/conf/config.ini.bak" ]; then
        echo "There already exists "/opt/RedstorProvision/$appName/conf/config.ini.bak"."
        echo "Have you forgotten to merge it into config.ini?"
        echo "If already merged, delete the .bak file and rerun the installation."
        echo "Quitting."
        exit
    fi
    if [ -f "/opt/RedstorProvision/$appName/conf/config.ini" ]; then
        echo "Taking backup of the config."
        cp "/opt/RedstorProvision/$appName/conf/config.ini" "/opt/RedstorProvision/$appName/conf/config.ini.bak"
    fi
fi

# Create the opt and www root folders
if [ ! -d "/opt/RedstorProvision" ]; then
    echo "Creating /opt/RedstorProvision."
    mkdir "/opt/RedstorProvision"
fi

if [ ! -d "/opt/RedstorProvision/$appName" ]; then
    echo "Creating /opt/RedstorProvision/$appName."
    mkdir "/opt/RedstorProvision/$appName"
    echo "Creating $wwwPath/$appName."
    mkdir "$wwwPath/$appName"
fi

echo "Copying files."
echo ""
cp -R ./www/* "$wwwPath/$appName/"
cp -R ./opt/* "/opt/RedstorProvision/$appName/"

echo "Installation complete."
echo "-----------------"
echo "1. Run the getUserHash script to obtain the userHash with the following command."
echo "php ./util/getUserHash.php"
echo "2. Edit the /opt/RedstorProvision/$appName/conf/config.ini to use this hash."
echo "3. Review any other settings in the above config file."
