<?php
// The OLBConnection class is an interface to the XML-RPC calls
// Once we create the OLBConnection object, we can use its
// 'request' method, passing the method name and an array of parameters
// See the following link for reference of XML-RPC calls
// https://yourAccountServer.com/Services/XmlRpc
// In ths example we are calling the service.AddGroup method
// The parameters are supplied as an array (order matters)
// Version 1.0
ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);

$baseName = basename(__DIR__);
$rootPath = "/opt/RedstorProvision/$baseName";
include('lib/OLBConnection.php');
require_once('lib/PHPMailer/PHPMailerAutoload.php');

// Parse the config file into $c array. Do not forget to edit the config file!
$c = parse_ini_file("$rootPath/conf/config.ini");

// POST parameters: pad them into array
// OUTPUT: $p array
$inputParams = [
    'grpName','uName','uPassword','colName',
    'eSend','uFullName','sLimit','nLicence'];
foreach ($inputParams as $param) {
    if (isset($_POST[$param])) $p[$param] = $_POST[$param];
    else exit('The required parameter '.$param.' was not set. Exitting.');
}

// Connection to the AS
$olb = new OLBConnection($c['AS'], $baseName);

// Top-level collection: add space, licences
if ($c['collection'] != '\\') {
    $colSize = $olb->request('group.GetSettings', array($c['collection']));
    $colSize = $colSize['maxTotalSpace'];
    $f0 = $olb->request('group.UpdateSettings', array(
        $c['collection'],       // col
        array('maxTotalSpace' => intval($colSize + $p['sLimit']))));
    if($f0 != 1) { echo "Added space to top-level collection.<br>"; }
    else { echo "Could not add space to top-level collection.<br>"; }
    
    foreach ([1, 3] as $pluginId) {
        $olb->request('group.AddPlugins', array(
            $c['collection'],
            $pluginId,
            intval($p['nLicence'])));
    }
}

// Customer collection: Create, add size, add licences
$colPath = ($c['collection'] == '\\')? $p['colName'] : $c['collection']."\\".$p['colName'];
$f1 = $olb->request('service.AddAdminGroup',
    array($colPath, $p['colName']));        // acc create key
if($f1 != 1) { echo "Created collection.<br>"; }
else { echo "Could not create collection.<br>"; }

//Here should get the size before increasing it
$grpSize = $olb->request('group.GetSettings', array($colPath));
$grpSize = $grpSize['maxTotalSpace'];

$f2 = $olb->request('group.UpdateSettings',
    array($colPath, array('maxTotalSpace' => $grpSize + intval($p['sLimit']))));
if($f2 != 1) { echo "Increased group space.<br>"; }
else { echo "Could not increase group space.<br>"; }

foreach ([1, 3] as $pluginId) {
    $olb->request('group.AddPlugins', array(
        $colPath,
        $pluginId,
        intval($p['nLicence'])));
}

// End group: Create, add size, add licences
$grpPath = $colPath."\\".$p['grpName'];
$grpCreateKey = substr(uniqid(), -6);

$f3 = $olb->request('service.AddGroup', array(
    $grpPath, $grpCreateKey));
if($f3 != 1) { echo "Created group.<br>"; }
else { echo "Could not create group.<br>"; }

//Here should get the size before increasing it
$grpSize2 = $olb->request('group.GetSettings', array($grpPath));
$grpSize2 = $grpSize2['maxTotalSpace'];

$f4 = $olb->request('group.UpdateSettings', array(
    $grpPath, array(
        'maxTotalSpace' => $grpSize2 + intval($p['sLimit']),
        'defaultAccountSize' => intval($p['sLimit']/$p['nLicence']*1024)
    )));
if($f4 != 1) { echo "Increased group space.<br>"; }
else { echo "Could not increase group space.<br>"; }

foreach ([1, 3] as $pluginId) {
    $olb->request('group.AddPlugins', array(
        $grpPath,
        $pluginId,
        intval($p['nLicence'])));
}

// Console user
$f5 = $olb->request('service.AddUserAccess2', array(
    $p['uName'],        // userName
    $p['uFullName'],    // fullName
    'Trial',            // desc
    $p['uPassword'],    // pass
    true,             // admin
    $colPath));       //col
if($f5 != 1) { echo "Added Console user.<br>"; }
else { echo "Could not add Console user.<br>"; }


// EMAIL    
// Email to the customer
if (isset($p['eSend']) && $p['eSend']=='yes') {
    // Sending report
    // Note: We are unnecessarily repeating the following code
    // TODO: There should be a wrapper class for the PHPMailer() which would make
    // the following cleaner
    $mail = new PHPMailer();
    $mail->IsSMTP();
    $mail->Host = $c['emailRelay'];
    $mail->Port = $c['emailRelayPort'];

    // Email delivery
    if(isset($c['emailRelaySecure']))
	$mail->SMTPSecure = $c['emailRelaySecure'];

    if(isset($c['emailRelayAuth']) && $c['emailRelayAuth'] == 'true') {
        $mail->SMTPAuth = true;
        if(isset($c['emailRelayUser']))
            $mail->Username = $c['emailRelayUser'];
        else
    	    exit("Need to configure the email relay authentication in config.ini.");
        if(isset($c['emailRelayPass']))
    	    $mail->Password = $c['emailRelayPass'];
        else
    	    exit("Need to configure the email relay authentication in config.ini.");
    }

    // Email delivery
    $mail->SetFrom($c['emailFromAddr'], $c['emailFromName']);
    $mail->AddAddress($p['uName']);
    $mail->AddCC($c['emailCcAddr']);
    $mail->Subject = 'Backup Pro trial for Redstor';
    $mail->AltBody = "To view the message, please use an HTML compatible email viewer!"; // optional, comment out and test
    ob_start();
    include("$rootPath/conf/emailContent.php");
    $content = ob_get_clean();
    $mail->MsgHTML($content);

    if(!$mail->Send()) echo "Mailer Error: ".$mail->ErrorInfo;
}

// Admin email to pre-sales
// Sending report
$mail = new PHPMailer();
$mail->IsSMTP();
$mail->Host = $c['emailRelay'];
$mail->Port = $c['emailRelayPort'];

// Email delivery
if(isset($c['emailRelaySecure']))
	$mail->SMTPSecure = $c['emailRelaySecure'];

if(isset($c['emailRelayAuth']) && $c['emailRelayAuth'] == 'true') {
    $mail->SMTPAuth = true;
    if(isset($c['emailRelayUser']))
	$mail->Username = $c['emailRelayUser'];
    else
	exit("Need to configure the email relay authentication in config.ini.");
    if(isset($c['emailRelayPass']))
	$mail->Password = $c['emailRelayPass'];
    else
	exit("Need to configure the email relay authentication in config.ini.");
}

$mail->SetFrom($c['emailFromAddr'], $c['emailFromName']);
$mail->AddAddress($c['emailCcAddr']);
$mail->Subject = 'Created new Backup Pro trial';
$mail->AltBody = "To view the message, please use an HTML compatible email viewer!"; // optional, comment out and test
ob_start();
include("$rootPath/conf/emailAdminContent.php");
$content = ob_get_clean();
$mail->MsgHTML($content);
if(!$mail->Send()) echo "Mailer Error: ".$mail->ErrorInfo;


?>
<html>
<body>
The group <b><?=$p['grpName']?></b> was created!
</body>
</html>



