Automated Provisioning of groups and licences 

The problem 

One of the daily tasks faced by Backup Pro Storage Platform administrators is to provision new groups and their required licences to the Storage Platform, either for newly signed customers, or for trials that may eventually become signed customers. 

At this point in time a number of steps must be completed to ensure that clients can be deployed after provisioning. This requires configuring the correct licence and space settings as per the request, gathering any additional download links, and passing the information over to the end user. 

Completing these steps consistently in a single pass can be tedious and prone to human error. 

 

Our solution 

The Automated Provisioning application is a web application which can be used for automating the collection/group provisioning process via a web browser, without the need to perform repetitive tasks via Storage Platform Console, and allows a degree of “self service” without requiring Console experience. 

The application: 

    Creates the groups and collections on the Storage Platform if they do not exist 

    Creates the Console access user using the customer’s email address, if the user does not exist. 

    Creates a customer email containing: 

    Details of how to access the Storage Platform 

    Download URL for Storage Platform Console 

    Download URLs for ESE and SE locked to the specified groups 

    Sends a summary email to the administrator for record keeping purposes. 

    Optionally sends the customer email directly to the customer. 

 

As the application is a PHP-based project, it can be incorporated into an existing LAMP web-server. The application is small and can be easily extended to add extra functionality for further integration, or modified to change branding. 

Disclaimer: The Automated Provisioning application is a proof of concept (PoC) application intended for customer feedback, and has not been stress tested or subjected to any security testing.  

Whilst we do not anticipate any issues if run on a public web server, it is recommended to run the application only on private web servers for the PoC phase of the application development.  

In no event will Redstor accept liability or be held responsible for any damage, disruption and/or loss of data as a result of using the Automated Provisioning application. 

 

Example 

The provisioning interface is displayed in a web browser. 

Image 

 

After clicking the 'Provision' button, a confirmation will be displayed on the screen. 

Image 

 

The customer automatically receives the following email. The user can click on the download links to download Console, and the required backup client installers. The backup client installers are generated on-demand once the customer clicks on the link, and the installers are set to use the customer's backup group. 

Image 

 

The following email is also sent to the Orders office, or Pre-sales office, to be kept on record for future reference. 

Image 

 

Prerequisites 

    Backup Pro Storage Platform 

    Access user with minimum collection admin level access. 

    A Linux machine with an Apache web server which can serve PHP. 

    Apache PHP modules: php5-xmlrpc, php5-curl 

This is a standard Apache Web Server configuration, but detailed steps are listed in the Appendix. 

 

Option 1: Installation with a pre-built vmWare .ova VirtualMachine image 

The application can be deployed directly to vmWare via the .ova image. This image provides a pre-built Linux Debian virtual machine, with the application, and the necessary prerequisites installed. Once the machine is deployed in vSphere, the application needs to be configured to be able to connect to the AccountServer. 
Note: This image already has vmware tools installed on the guest. 

     Deploy .ova and boot the machine (ESX/ESXi 4.0 or later required). The .ova is available via the link below. 
    https://downloads.redstor.com/tools/BackupPro/SPProvisioning.ova 

    Log in with the following default credentials 
    user: provision 
    password: Password123 

    Change the default password with the following command. 
    passwd 

    Obtain the userHash (used in the next step) with the following command. This will prompt for the Console credentials. A Console user with at least collection admin permissions is required. 
    php  

    Edit the config file, entering the userHash obtained in the above step. 
    sudo nano /opt/RedstorProvision/provisioningApp/util/getUserHash.php 

     

    The application is ready to be accessed via the browser via the following address. 
     
     
     

 

 

 

 

Option 2: Installation on Linux web server 

First, log in as a user with write (and sudo) permissions to the folder from which Apache serves its pages (usually the /var/www/html/ folder). The steps for installing the provisioning application are as follows. 

1. Download the app package to a temporary location: e.g. to /tmp, your desktop, or /home folder and unpack it with the with the following commands. Note: In this example, when prompted by the installer, we arbitrarily chose 'provisioningApp' as the application name. 

wget --no-check-certificate \ 
https://downloads.redstor.com/tools/BackupPro/RedstorProvision.tar.gz 
tar –xvf RedstorProvision.tar.gz 

2. Navigate to the resulting folder and install the application by running the install.sh script and following the prompts. 

cd RedstorProvision 
sudo ./install.sh 

3. Run the provided utility to obtain the userHash (a base64-encoded authentication string). This hash code is to be used in the next step for the authentication to avoid storing the collection admin credentials in plaintext. 

php ./util/getUserHash.php 

4. Edit the config file, pasting the userHash from the previous step, adjust the AccountServer address, and any required email addresses. 

sudo nano /opt/RedstorProvision/provisioningApp/conf/config.ini 

5. We can now use the application via the web browser by navigating to the following address. 

http://hostname/provisioningApp 

 

Example: An example config.ini file. 

; This is a config file for the Provisioning application 
; Comments start with ';', just like in php.ini 
; Make sure you edit these before use 
; Section names are between square brackets [] 
; all the lines have to end with ; 
 
[General] 
AS = 'https://myAccountServer.example.com'; 
userHash = 'fwpokwepfokpo345634='; 
collection = '\'; 
emailRelay = '123.123.123.123'; 
emailCcAddr = 'presales@example.com'; 
emailFromAddr = 'provisioning@example.com'; 
emailFromName = 'Example Presales'; 
 

 

 

 

 

 

 

 

Appendix: Detailed steps and prerequisites for installing a web server 

Install Linux Debian (during installation tick 'apache2' to include the Apache web server). In our testing we have used the small netinst .iso image. 

Add our user, (optional, potentially insecure) allow it to run elevated commands. 

useradd provision 
usermod -a -G sudo provision 

Log in as our new user. 

su provision 

Upgrade your OS. Do not skip this step! 

sudo apt-get update 
sudo apt-get upgrade 

If apache2 was not installed as part of the OS install, run the following. Also, make sure our user is in the www-data group. 

sudo apt-get install apache2 
sudo usermod –a -G www-data provision 

Install PHP. Otherwise the PHP scripts will simply be printed out on screen instead of being executed. 

sudo apt-get install php5 

Install xmlrpc php library with the following command. 

sudo apt-get install php5-xmlrpc 

 

Note: The XML-RPC library is required for communicating with the AccountServer. If not present, the application will crash with an error similar to the below. 

Fatal error: Call to undefined function xmlrpc_encode_request() in /var/www/html/lib/OLBConnection.php on line 36 

 

Install the cURL php library. This is required for communicating with the AccountServer. 

sudo apt-get install php5-curl 

Restart the Apache server following the addition of the xmlrpc and cURL libraries. 

sudo apachectl restart 

Allow our user to write to Apache's html dir. 

sudo chown -R root:www-data /var/www/html 
sudo chmod -R ug+rw /var/www/html 

Remove the default Apache welcome page. 

rm /var/www/html/index.html 

The Apache web server is now ready for an installation and deployment of the application with the steps in the Installation section of this document. 

 

Note: Other Linux distributions 

There are many other Linux distributions available and their package names may vary. For instance, Ubuntu's required packages: 
sudo apt-get install apache2 php php-xmlrpc php-curl libapache2-mod-php 

In this article we use Debian Linux. For details on installing the prerequisite packages on any other distribution, please follow your specific distribution's guidelines. 

Note: Authenticating with SMTP email relay 

If using smtp.gmail.com as your relay, use port 587 and smtp.gmail.com as the 'emailRelay' in config.ini. 
Also, your gmail account needs to 'Allow less secure apps' as per the article below. 
https://support.google.com/accounts/answer/6010255 

 
